@@ -2,13 +2,16 @@ from autoconf import conf
 
 dir(conf)
 from autoarray import exc
-from autoarray import masked
 from autoarray import plot
 from autoarray import simulator
 from autoarray import util
 from autoarray.dataset import data_converter
 from autoarray.dataset.imaging import Imaging as imaging
+from autoarray.dataset.imaging import MaskedImaging as masked_imaging
 from autoarray.dataset.interferometer import Interferometer as interferometer
+from autoarray.dataset.interferometer import (
+    MaskedInterferometer as masked_interferometer,
+)
 from autoarray.fit.fit import fit
 from autoarray.mask.mask import Mask as mask
 from autoarray.operators.convolver import Convolver as convolver
@@ -26,5 +29,7 @@ from autoarray.structures.grids import (
 )
 from autoarray.structures.kernel import Kernel as kernel
 from autoarray.structures.visibilities import Visibilities as visibilities
+from autoarray.structures.arrays import MaskedArray as masked_array
+from autoarray.structures.grids import MaskedGrid as masked_grid
 
-__version__ = '0.7.10'
+__version__ = '0.8.2'
