@@ -17,7 +17,7 @@ def make_grid():
         sub_size=1,
     )
 
-    return aa.masked.grid.from_mask(mask=mask)
+    return aa.masked_grid.from_mask(mask=mask)
 
 
 class TestGridAPI:
@@ -413,12 +413,66 @@ class TestGridAPI:
             assert grid.sub_size == 2
 
     class TestGridBoundingBox:
-        def test__grid_bounding_box__uniform_box__makes_grid_with_correct_pixel_scales_and_origin(
+        def test__grid_bounding_box__align_at_corners__grid_corner_is_at_bounding_box_corner(
             self
         ):
 
             grid = aa.grid.bounding_box(
-                bounding_box=[2.0, -2.0, 2.0, -2.0], shape_2d=(3, 3)
+                bounding_box=[-2.0, 2.0, -2.0, 2.0],
+                shape_2d=(3, 3),
+                buffer_around_corners=False,
+            )
+
+            assert grid.in_1d == pytest.approx(
+                np.array(
+                    [
+                        [1.3333, -1.3333],
+                        [1.3333, 0.0],
+                        [1.3333, 1.3333],
+                        [0.0, -1.3333],
+                        [0.0, 0.0],
+                        [0.0, 1.3333],
+                        [-1.3333, -1.3333],
+                        [-1.3333, 0.0],
+                        [-1.3333, 1.3333],
+                    ]
+                ),
+                1.0e-4,
+            )
+
+            assert grid.pixel_scales == pytest.approx((1.33333, 1.3333), 1.0e-4)
+            assert grid.origin == (0.0, 0.0)
+
+            grid = aa.grid.bounding_box(
+                bounding_box=[-2.0, 2.0, -2.0, 2.0],
+                shape_2d=(2, 3),
+                buffer_around_corners=False,
+            )
+
+            assert grid.in_1d == pytest.approx(
+                np.array(
+                    [
+                        [1.0, -1.3333],
+                        [1.0, 0.0],
+                        [1.0, 1.3333],
+                        [-1.0, -1.3333],
+                        [-1.0, 0.0],
+                        [-1.0, 1.3333],
+                    ]
+                ),
+                1.0e-4,
+            )
+            assert grid.pixel_scales == pytest.approx((2.0, 1.33333), 1.0e4)
+            assert grid.origin == (0.0, 0.0)
+
+        def test__grid_bounding_box__uniform_box__buffer_around_corners__makes_grid_with_correct_pixel_scales_and_origin(
+            self
+        ):
+
+            grid = aa.grid.bounding_box(
+                bounding_box=[-2.0, 2.0, -2.0, 2.0],
+                shape_2d=(3, 3),
+                buffer_around_corners=True,
             )
 
             assert (
@@ -441,7 +495,9 @@ class TestGridAPI:
             assert grid.origin == (0.0, 0.0)
 
             grid = aa.grid.bounding_box(
-                bounding_box=[2.0, -2.0, 2.0, -2.0], shape_2d=(2, 3)
+                bounding_box=[-2.0, 2.0, -2.0, 2.0],
+                shape_2d=(2, 3),
+                buffer_around_corners=True,
             )
 
             assert (
@@ -461,7 +517,10 @@ class TestGridAPI:
             assert grid.origin == (0.0, 0.0)
 
             grid = aa.grid.bounding_box(
-                bounding_box=[10.0, 8.0, 3.0, -2.0], shape_2d=(3, 3), store_in_1d=True
+                bounding_box=[8.0, 10.0, -2.0, 3.0],
+                shape_2d=(3, 3),
+                store_in_1d=True,
+                buffer_around_corners=True,
             )
 
             assert grid == pytest.approx(
@@ -500,7 +559,10 @@ class TestGridAPI:
             assert grid.origin == (9.0, 0.5)
 
             grid = aa.grid.bounding_box(
-                bounding_box=[10.0, 8.0, 3.0, -2.0], shape_2d=(3, 3), store_in_1d=False
+                bounding_box=[8.0, 10.0, -2.0, 3.0],
+                shape_2d=(3, 3),
+                store_in_1d=False,
+                buffer_around_corners=True,
             )
 
             assert grid.in_2d == pytest.approx(
@@ -538,7 +600,7 @@ class TestGridMaskedAPI:
         def test__grid__makes_scaled_grid_with_pixel_scale(self):
 
             mask = aa.mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0)
-            grid = aa.masked.grid.manual_2d(
+            grid = aa.masked_grid.manual_2d(
                 grid=[[[1.0, 2.0], [3.0, 4.0]], [[5.0, 6.0], [7.0, 8.0]]], mask=mask
             )
 
@@ -556,7 +618,7 @@ class TestGridMaskedAPI:
             mask = aa.mask.manual(
                 [[True, False], [False, False]], pixel_scales=1.0, origin=(0.0, 1.0)
             )
-            grid = aa.masked.grid.manual_1d(
+            grid = aa.masked_grid.manual_1d(
                 grid=[[3.0, 4.0], [5.0, 6.0], [7.0, 8.0]], mask=mask
             )
 
@@ -572,7 +634,7 @@ class TestGridMaskedAPI:
             mask = aa.mask.manual(
                 [[False], [True]], sub_size=2, pixel_scales=1.0, origin=(0.0, 1.0)
             )
-            grid = aa.masked.grid.manual_2d(
+            grid = aa.masked_grid.manual_2d(
                 grid=[
                     [[1.0, 2.0], [3.0, 4.0]],
                     [[5.0, 6.0], [7.0, 8.0]],
@@ -607,7 +669,7 @@ class TestGridMaskedAPI:
             assert grid.origin == (0.0, 1.0)
             assert grid.sub_size == 2
 
-            grid = aa.masked.grid.manual_2d(
+            grid = aa.masked_grid.manual_2d(
                 grid=[
                     [[1.0, 2.0], [3.0, 4.0]],
                     [[5.0, 6.0], [7.0, 8.0]],
@@ -654,17 +716,17 @@ class TestGridMaskedAPI:
 
             with pytest.raises(exc.GridException):
                 mask = aa.mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0, sub_size=1)
-                aa.masked.grid.manual_2d(grid=[[[1.0, 1.0], [3.0, 3.0]]], mask=mask)
+                aa.masked_grid.manual_2d(grid=[[[1.0, 1.0], [3.0, 3.0]]], mask=mask)
 
             with pytest.raises(exc.GridException):
                 mask = aa.mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0, sub_size=2)
-                aa.masked.grid.manual_2d(
+                aa.masked_grid.manual_2d(
                     grid=[[[1.0, 1.0], [2.0, 2.0]], [[3.0, 3.0], [4.0, 4.0]]], mask=mask
                 )
 
             with pytest.raises(exc.GridException):
                 mask = aa.mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0, sub_size=2)
-                aa.masked.grid.manual_2d(
+                aa.masked_grid.manual_2d(
                     grid=[
                         [[1.0, 1.0], [2.0, 2.0]],
                         [[3.0, 3.0], [4.0, 4.0]],
@@ -681,7 +743,7 @@ class TestGridMaskedAPI:
                 mask = aa.mask.manual(
                     mask_2d=[[False, False], [True, False]], sub_size=1
                 )
-                aa.masked.grid.manual_1d(
+                aa.masked_grid.manual_1d(
                     grid=[[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]], mask=mask
                 )
 
@@ -689,17 +751,17 @@ class TestGridMaskedAPI:
                 mask = aa.mask.manual(
                     mask_2d=[[False, False], [True, False]], sub_size=1
                 )
-                aa.masked.grid.manual_1d(grid=[[1.0, 1.0], [2.0, 2.0]], mask=mask)
+                aa.masked_grid.manual_1d(grid=[[1.0, 1.0], [2.0, 2.0]], mask=mask)
 
             with pytest.raises(exc.GridException):
                 mask = aa.mask.manual(mask_2d=[[False, True], [True, True]], sub_size=2)
-                aa.masked.grid.manual_2d(
+                aa.masked_grid.manual_2d(
                     grid=[[[1.0, 1.0], [2.0, 2.0], [4.0, 4.0]]], mask=mask
                 )
 
             with pytest.raises(exc.GridException):
                 mask = aa.mask.manual(mask_2d=[[False, True], [True, True]], sub_size=2)
-                aa.masked.grid.manual_2d(
+                aa.masked_grid.manual_2d(
                     grid=[[[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0], [5.0, 5.0]]],
                     mask=mask,
                 )
@@ -719,7 +781,7 @@ class TestGridMaskedAPI:
                 mask_2d=mask, sub_size=1, pixel_scales=(2.0, 2.0)
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             assert type(grid) == grids.Grid
             assert grid == pytest.approx(grid_via_util, 1e-4)
@@ -740,12 +802,12 @@ class TestGridMaskedAPI:
                 mask_2d=mask, pixel_scales=(3.0, 3.0), sub_size=2
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask, store_in_1d=True)
+            grid = aa.masked_grid.from_mask(mask=mask, store_in_1d=True)
 
             assert len(grid.shape) == 2
             assert grid == pytest.approx(grid_via_util, 1e-4)
 
-            grid = aa.masked.grid.from_mask(mask=mask, store_in_1d=False)
+            grid = aa.masked_grid.from_mask(mask=mask, store_in_1d=False)
 
             assert len(grid.shape) == 3
 
@@ -802,7 +864,7 @@ class TestGrid:
             mask_2d=blurring_mask_util, pixel_scales=(2.0, 2.0), sub_size=1
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         blurring_grid = grid.blurring_grid_from_kernel_shape(kernel_shape_2d=(3, 5))
 
@@ -867,6 +929,32 @@ class TestGrid:
         )
         assert grid.shape_2d_scaled == (8.5, 8.0)
 
+    def test__flipped_property__returns_grid_as_x_then_y(self):
+
+        grid = aa.grid.manual_2d(
+            grid=[[[1.0, 2.0], [3.0, 4.0]], [[5.0, 6.0], [7.0, 8.0]]], pixel_scales=1.0
+        )
+
+        assert (
+            grid.in_1d_flipped
+            == np.array([[2.0, 1.0], [4.0, 3.0], [6.0, 5.0], [8.0, 7.0]])
+        ).all()
+        assert (
+            grid.in_2d_flipped
+            == np.array([[[2.0, 1.0], [4.0, 3.0]], [[6.0, 5.0], [8.0, 7.0]]])
+        ).all()
+
+        grid = aa.grid.manual_2d(
+            grid=[[[1.0, 2.0], [3.0, 4.0], [5.0, 6.0]]], pixel_scales=1.0
+        )
+
+        assert (
+            grid.in_1d_flipped == np.array([[2.0, 1.0], [4.0, 3.0], [6.0, 5.0]])
+        ).all()
+        assert (
+            grid.in_2d_flipped == np.array([[[2.0, 1.0], [4.0, 3.0], [6.0, 5.0]]])
+        ).all()
+
     def test__in_radians(self):
         mask = np.array(
             [
@@ -877,7 +965,7 @@ class TestGrid:
         )
         mask = aa.mask.manual(mask_2d=mask, pixel_scales=(2.0, 2.0))
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         assert grid.in_radians[0, 0] == pytest.approx(0.00000969627362, 1.0e-8)
         assert grid.in_radians[0, 1] == pytest.approx(0.00000484813681, 1.0e-8)
@@ -928,7 +1016,7 @@ class TestGrid:
         )
         mask = aa.mask.manual(mask_2d=mask, pixel_scales=(2.0, 2.0))
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         grid_with_interp = grid.new_grid_with_interpolator(
             pixel_scale_interpolation_grid=1.0
@@ -954,7 +1042,7 @@ class TestGrid:
         )
         mask = aa.mask.manual(mask_2d=mask, pixel_scales=(2.0, 2.0))
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         grid.new_grid_with_binned_grid(binned_grid=1)
 
@@ -1012,7 +1100,7 @@ class TestGrid:
             mask_2d=np.full((5, 4), False), pixel_scales=(2.0, 2.0), sub_size=2
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=(3, 3))
 
@@ -1029,7 +1117,7 @@ class TestGrid:
             mask_2d=np.full((2, 5), False), pixel_scales=(8.0, 8.0), sub_size=4
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=(5, 5))
 
@@ -1066,7 +1154,7 @@ class TestGrid:
             mask_2d=np.full((5, 4), False), pixel_scales=(2.0, 2.0), sub_size=2
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         grid = grid.new_grid_with_interpolator(pixel_scale_interpolation_grid=0.1)
 
@@ -1103,14 +1191,57 @@ class TestGrid:
             mask_2d=mask, sub_size=2
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         assert grid.regions._sub_border_1d_indexes == pytest.approx(
             sub_border_1d_indexes_util, 1e-4
         )
 
+    def test__square_distance_from_coordinate_array(self):
 
-class TestGridBorder(object):
+        mask = aa.mask.manual(
+            [[True, False], [False, False]], pixel_scales=1.0, origin=(0.0, 1.0)
+        )
+        grid = aa.masked_grid.manual_1d(
+            grid=[[1.0, 1.0], [2.0, 3.0], [1.0, 2.0]], mask=mask
+        )
+
+        square_distances = grid.squared_distances_from_coordinate(coordinate=(0.0, 0.0))
+
+        assert (square_distances.in_1d == np.array([2.0, 13.0, 5.0])).all()
+        assert (square_distances.mask == mask).all()
+
+        square_distances = grid.squared_distances_from_coordinate(coordinate=(0.0, 1.0))
+
+        assert (square_distances.in_1d == np.array([1.0, 8.0, 2.0])).all()
+        assert (square_distances.mask == mask).all()
+
+    def test__distance_from_coordinate_array(self):
+
+        mask = aa.mask.manual(
+            [[True, False], [False, False]], pixel_scales=1.0, origin=(0.0, 1.0)
+        )
+        grid = aa.masked_grid.manual_1d(
+            grid=[[1.0, 1.0], [2.0, 3.0], [1.0, 2.0]], mask=mask
+        )
+
+        square_distances = grid.distances_from_coordinate(coordinate=(0.0, 0.0))
+
+        assert (
+            square_distances.in_1d
+            == np.array([np.sqrt(2.0), np.sqrt(13.0), np.sqrt(5.0)])
+        ).all()
+        assert (square_distances.mask == mask).all()
+
+        square_distances = grid.distances_from_coordinate(coordinate=(0.0, 1.0))
+
+        assert (
+            square_distances.in_1d == np.array([1.0, np.sqrt(8.0), np.sqrt(2.0)])
+        ).all()
+        assert (square_distances.mask == mask).all()
+
+
+class TestGridBorder:
     def test__sub_border_grid_for_simple_mask(self):
         mask = np.array(
             [
@@ -1126,7 +1257,7 @@ class TestGridBorder(object):
 
         mask = aa.mask.manual(mask_2d=mask, pixel_scales=(2.0, 2.0), sub_size=2)
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         assert (
             grid.sub_border_grid
@@ -1151,7 +1282,7 @@ class TestGridBorder(object):
             shape_2d=(30, 30), radius=1.0, pixel_scales=(0.1, 0.1), sub_size=1
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         grid_to_relocate = grids.Grid(
             grid=np.array([[0.1, 0.1], [0.3, 0.3], [-0.1, -0.2]]), mask=mask
@@ -1169,7 +1300,7 @@ class TestGridBorder(object):
             shape_2d=(30, 30), radius=1.0, pixel_scales=(0.1, 0.1), sub_size=2
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         grid_to_relocate = grids.Grid(
             grid=np.array([[0.1, 0.1], [0.3, 0.3], [-0.1, -0.2]]), mask=mask
@@ -1188,7 +1319,7 @@ class TestGridBorder(object):
             shape_2d=(30, 30), radius=1.0, pixel_scales=(0.1, 0.1), sub_size=1
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         grid_to_relocate = grids.Grid(
             grid=np.array([[10.1, 0.0], [0.0, 10.1], [-10.1, -10.1]]), mask=mask
@@ -1206,7 +1337,7 @@ class TestGridBorder(object):
             shape_2d=(30, 30), radius=1.0, pixel_scales=(0.1, 0.1), sub_size=2
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         grid_to_relocate = grids.Grid(
             grid=np.array([[10.1, 0.0], [0.0, 10.1], [-10.1, -10.1]]), mask=mask
@@ -1231,7 +1362,7 @@ class TestGridBorder(object):
             sub_size=1,
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         grid_to_relocate = grids.Grid(
             grid=np.array([[11.1, 1.0], [1.0, 11.1], [-11.1, -11.1]]),
@@ -1258,7 +1389,7 @@ class TestGridBorder(object):
             sub_size=2,
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         grid_to_relocate = grids.Grid(
             grid=np.array([[11.1, 1.0], [1.0, 11.1], [-11.1, -11.1]]), mask=mask
@@ -1284,13 +1415,13 @@ class TestGridIrregular:
     def test__pixelization_grid__attributes(self):
         pix_grid = grids.GridIrregular(
             grid=np.array([[1.0, 1.0], [2.0, 2.0]]),
-            nearest_irregular_1d_index_for_mask_1d_index=np.array([0, 1]),
+            nearest_pixelization_1d_index_for_mask_1d_index=np.array([0, 1]),
         )
 
         assert type(pix_grid) == grids.GridIrregular
         assert (pix_grid == np.array([[1.0, 1.0], [2.0, 2.0]])).all()
         assert (
-            pix_grid.nearest_irregular_1d_index_for_mask_1d_index == np.array([0, 1])
+            pix_grid.nearest_pixelization_1d_index_for_mask_1d_index == np.array([0, 1])
         ).all()
 
     def test__from_unmasked_sparse_shape_and_grid(self):
@@ -1302,7 +1433,7 @@ class TestGridIrregular:
             sub_size=1,
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
             unmasked_sparse_shape=(10, 10), grid=grid
@@ -1315,7 +1446,7 @@ class TestGridIrregular:
         assert (sparse_grid.sparse == pixelization_grid).all()
         assert (
             sparse_grid.sparse_1d_index_for_mask_1d_index
-            == pixelization_grid.nearest_irregular_1d_index_for_mask_1d_index
+            == pixelization_grid.nearest_pixelization_1d_index_for_mask_1d_index
         ).all()
 
 
@@ -1330,7 +1461,7 @@ class TestSparseGrid:
                 sub_size=1,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
                 unmasked_sparse_shape=(10, 10), grid=grid
@@ -1408,7 +1539,7 @@ class TestSparseGrid:
                 sub_size=1,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
                 unmasked_sparse_shape=(3, 3), grid=grid
@@ -1439,7 +1570,7 @@ class TestSparseGrid:
                 sub_size=1,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
                 unmasked_sparse_shape=(4, 3), grid=grid
@@ -1478,7 +1609,7 @@ class TestSparseGrid:
                 sub_size=1,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
                 unmasked_sparse_shape=(3, 4), grid=grid
@@ -1519,7 +1650,7 @@ class TestSparseGrid:
                 sub_size=1,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             # Without a change in origin, only the central 3 pixels are paired as the unmasked sparse grid overlaps
             # the central (3x3) pixels only.
@@ -1554,7 +1685,7 @@ class TestSparseGrid:
                 sub_size=1,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             # Without a change in origin, only the central 3 pixels are paired as the unmasked sparse grid overlaps
             # the central (3x3) pixels only.
@@ -1577,7 +1708,7 @@ class TestSparseGrid:
         def test__from_grid_and_unmasked_shape__sets_up_with_correct_shape_and_pixel_scales(
             self, mask_7x7
         ):
-            grid = aa.masked.grid.from_mask(mask=mask_7x7)
+            grid = aa.masked_grid.from_mask(mask=mask_7x7)
 
             sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
                 grid=grid, unmasked_sparse_shape=(3, 3)
@@ -1618,7 +1749,7 @@ class TestSparseGrid:
                 sub_size=1,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
                 unmasked_sparse_shape=(4, 3), grid=grid
@@ -1657,7 +1788,7 @@ class TestSparseGrid:
                 sub_size=1,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
                 unmasked_sparse_shape=(3, 4), grid=grid
@@ -1696,7 +1827,7 @@ class TestSparseGrid:
                 sub_size=1,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
                 unmasked_sparse_shape=(3, 3), grid=grid
@@ -1738,7 +1869,7 @@ class TestSparseGrid:
                 sub_size=1,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             weight_map = np.ones(mask.pixels_in_mask)
 
@@ -1786,7 +1917,7 @@ class TestSparseGrid:
                 sub_size=2,
             )
 
-            grid = aa.masked.grid.from_mask(mask=mask)
+            grid = aa.masked_grid.from_mask(mask=mask)
 
             weight_map = np.ones(mask.pixels_in_mask)
             weight_map[0:15] = 0.00000001
@@ -2264,7 +2395,7 @@ class TestInterpolator:
             result[0] = 1
             return result
 
-        grid = aa.masked.grid.from_mask(
+        grid = aa.masked_grid.from_mask(
             mask=aa.mask.unmasked(shape_2d=(3, 3), pixel_scales=(1.0, 1.0), sub_size=1)
         )
 
@@ -2274,7 +2405,7 @@ class TestInterpolator:
         assert values.shape == (9,)
         assert (values == np.array([[1, 0, 0, 0, 0, 0, 0, 0, 0]])).all()
 
-        grid = aa.masked.grid.from_mask(
+        grid = aa.masked_grid.from_mask(
             mask=aa.mask.unmasked(shape_2d=(3, 3), pixel_scales=(1.0, 1.0), sub_size=1)
         )
         grid.interpolator = grids.Interpolator.from_mask_grid_and_pixel_scale_interpolation_grids(
@@ -2295,7 +2426,7 @@ class TestInterpolator:
             result[0, :] = 1
             return result
 
-        grid = aa.masked.grid.from_mask(
+        grid = aa.masked_grid.from_mask(
             mask=aa.mask.unmasked(shape_2d=(3, 3), pixel_scales=(1.0, 1.0), sub_size=1)
         )
 
@@ -2310,7 +2441,7 @@ class TestInterpolator:
             )
         ).all()
 
-        grid = aa.masked.grid.from_mask(
+        grid = aa.masked_grid.from_mask(
             mask=aa.mask.unmasked(shape_2d=(3, 3), pixel_scales=(1.0, 1.0), sub_size=1)
         )
         grid.interpolator = grids.Interpolator.from_mask_grid_and_pixel_scale_interpolation_grids(
@@ -2349,7 +2480,7 @@ class TestInterpolator:
             outer_radius=8.0,
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         true_grid_radii = grid_radii_from_grid(profile=None, grid=grid)
 
@@ -2382,7 +2513,7 @@ class TestInterpolator:
             centre=(3.0, 3.0),
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         true_grid_radii = grid_radii_from_grid(profile=None, grid=grid)
 
@@ -2415,7 +2546,7 @@ class TestInterpolator:
             centre=(3.0, 3.0),
         )
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         true_grid_radii = grid_radii_from_grid(profile=None, grid=grid)
 
@@ -2474,49 +2605,127 @@ class TestInterpolator:
         assert np.max(true_grid_radii[:, 1] - interpolated_grid_radii_x) < 0.1
 
 
-test_positions_dir = "{}/../test_files/positions/".format(
+test_coordinates_dir = "{}/../test_files/coordinates/".format(
     os.path.dirname(os.path.realpath(__file__))
 )
 
 
-class TestPositions:
-    def test__input_is_list_of_lists__converted_to_irregular_grids(self):
+class MockCoordinateInput:
+    def __init__(self):
+        pass
 
-        positions = aa.positions(positions=[[[1.0, 1.0], [2.0, 2.0]]])
+    @grids.convert_coordinates_to_grid
+    def float_values_from_grid(self, grid):
+        return np.ones(shape=grid.shape[0])
 
-        assert type(positions[0][0]) == grids.GridIrregular
-        assert (positions[0][0] == np.array([1.0, 1.0])).all()
+    @grids.convert_coordinates_to_grid
+    def tuple_values_from_grid(self, grid):
+        return np.multiply(2.0, grid)
 
-        assert type(positions[0][1]) == grids.GridIrregular
-        assert (positions[0][1] == np.array([2.0, 2.0])).all()
+    @grids.convert_coordinates_to_grid
+    def float_values_from_grid_returns_list(self, grid):
+        return [np.ones(shape=grid.shape[0]), 2.0 * np.ones(shape=grid.shape[0])]
 
-        positions = aa.positions(positions=[[[1.0, 1.0], [2.0, 2.0]], [[3.0, 3.0]]])
+    @grids.convert_coordinates_to_grid
+    def tuple_values_from_grid_returns_list(self, grid):
+        return [np.multiply(1.0, grid), np.multiply(2.0, grid)]
 
-        assert type(positions[0][0]) == grids.GridIrregular
-        assert (positions[0][0] == np.array([1.0, 1.0])).all()
 
-        assert type(positions[0][1]) == grids.GridIrregular
-        assert (positions[0][1] == np.array([2.0, 2.0])).all()
+class TestCoordinates:
+    def test__converts_to_and_from_pixels(self):
 
-        assert type(positions[1][0]) == grids.GridIrregular
-        assert (positions[1][0] == np.array([3.0, 3.0])).all()
-
-    def test__load_positions__retains_list_structure(self):
-        positions = aa.positions.from_file(
-            positions_path=test_positions_dir + "positions_test.dat"
+        mask = aa.mask.manual(
+            mask_2d=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
-        assert positions == [
-            [[1.0, 1.0], [2.0, 2.0]],
-            [[3.0, 3.0], [4.0, 4.0], [5.0, 6.0]],
+        coordinates = aa.coordinates(coordinates=[[(1.0, -1.0), (1.0, 1.0)]], mask=mask)
+
+        assert type(coordinates.scaled) == grids.Coordinates
+        assert coordinates.scaled == [[(1.0, -1.0), (1.0, 1.0)]]
+        assert coordinates.pixels == [[(0, 0), (0, 1)]]
+
+        coordinates = aa.coordinates.from_pixels_and_mask(
+            pixels=[[(0, 0), (0, 1)]], mask=mask
+        )
+
+        assert coordinates.scaled == [[(1.0, -1.0), (1.0, 1.0)]]
+        assert coordinates.pixels == [[(0, 0), (0, 1)]]
+
+    def test__input_is_list_of_tuples__converts_to_irregular_1d_grid(self):
+
+        coordinates = aa.coordinates(coordinates=[[(1.0, 1.0), (2.0, 2.0)]])
+
+        assert coordinates == [[(1.0, 1.0), (2.0, 2.0)]]
+        assert type(coordinates.in_1d) == grids.GridIrregular
+        assert (coordinates.in_1d == np.array([[1.0, 1.0], [2.0, 2.0]])).all()
+        assert (coordinates.list_in_1d[0] == np.array([[1.0, 1.0], [2.0, 2.0]])).all()
+
+        coordinates = aa.coordinates(
+            coordinates=[[(1.0, 1.0), (2.0, 2.0)], [(3.0, 3.0)]]
+        )
+
+        assert coordinates == [[(1.0, 1.0), (2.0, 2.0)], [(3.0, 3.0)]]
+        assert type(coordinates.in_1d) == grids.GridIrregular
+        assert (
+            coordinates.in_1d == np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 3.0]])
+        ).all()
+        assert (coordinates.list_in_1d[0] == np.array([[1.0, 1.0], [2.0, 2.0]])).all()
+        assert (coordinates.list_in_1d[1] == np.array([[3.0, 3.0]])).all()
+
+    def test__retain_original_list_of_tuples_from_a_1d_grid(self):
+
+        coordinates = aa.coordinates(coordinates=[[(1.0, 1.0), (2.0, 2.0)]])
+
+        coordinates_from_1d = coordinates.from_1d_coordinates(
+            coordinates_1d=np.array([[1.0, 1.0], [2.0, 2.0]])
+        )
+
+        assert type(coordinates_from_1d) == grids.Coordinates
+        assert coordinates_from_1d == [[(1.0, 1.0), (2.0, 2.0)]]
+
+        coordinates = aa.coordinates(
+            coordinates=[[(1.0, 1.0), (2.0, 2.0)], [(3.0, 3.0)]]
+        )
+
+        coordinates_from_1d = coordinates.from_1d_coordinates(
+            coordinates_1d=np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 3.0]])
+        )
+
+        assert type(coordinates_from_1d) == grids.Coordinates
+        assert coordinates_from_1d == [[(1.0, 1.0), (2.0, 2.0)], [(3.0, 3.0)]]
+
+    def test__retain_origin_list_but_as_floats_for_single_values(self):
+
+        coordinates = aa.coordinates(coordinates=[[(1.0, 1.0), (2.0, 2.0)]])
+
+        values_from_1d = coordinates.from_1d_values(values_1d=np.array([1.0, 2.0]))
+
+        assert values_from_1d == [[1.0, 2.0]]
+
+        coordinates = aa.coordinates(
+            coordinates=[[(1.0, 1.0), (2.0, 2.0)], [(3.0, 3.0)]]
+        )
+
+        values_from_1d = coordinates.from_1d_values(values_1d=np.array([1.0, 2.0, 3.0]))
+
+        assert values_from_1d == [[1.0, 2.0], [3.0]]
+
+    def test__load_coordinates__retains_list_structure(self):
+        coordinates = aa.coordinates.from_file(
+            file_path=test_coordinates_dir + "coordinates_test.dat"
+        )
+
+        assert coordinates == [
+            [(1.0, 1.0), (2.0, 2.0)],
+            [(3.0, 3.0), (4.0, 4.0), (5.0, 6.0)],
         ]
 
-    def test__output_positions(self):
-        positions = aa.positions(
-            [[[4.0, 4.0], [5.0, 5.0]], [[6.0, 6.0], [7.0, 7.0], [8.0, 8.0]]]
+    def test__output_coordinates_to_file(self):
+        coordinates = aa.coordinates(
+            [[(4.0, 4.0), (5.0, 5.0)], [(6.0, 6.0), (7.0, 7.0), (8.0, 8.0)]]
         )
 
-        output_data_dir = "{}/../test_files/positions/output_test/".format(
+        output_data_dir = "{}/../test_files/coordinates/output_test/".format(
             os.path.dirname(os.path.realpath(__file__))
         )
         if os.path.exists(output_data_dir):
@@ -2524,13 +2733,63 @@ class TestPositions:
 
         os.makedirs(output_data_dir)
 
-        positions.output_to_file(positions_path=output_data_dir + "positions_test.dat")
+        coordinates.output_to_file(file_path=output_data_dir + "coordinates_test.dat")
 
-        positions = aa.positions.from_file(
-            positions_path=output_data_dir + "positions_test.dat"
+        coordinates = aa.coordinates.from_file(
+            file_path=output_data_dir + "coordinates_test.dat"
         )
 
-        assert positions == [
-            [[4.0, 4.0], [5.0, 5.0]],
-            [[6.0, 6.0], [7.0, 7.0], [8.0, 8.0]],
+        assert coordinates == [
+            [(4.0, 4.0), (5.0, 5.0)],
+            [(6.0, 6.0), (7.0, 7.0), (8.0, 8.0)],
+        ]
+
+        with pytest.raises(FileExistsError):
+            coordinates.output_to_file(
+                file_path=output_data_dir + "coordinates_test.dat"
+            )
+
+        coordinates.output_to_file(
+            file_path=output_data_dir + "coordinates_test.dat", overwrite=True
+        )
+
+    def test__convert_coordinates_decorator__coordinates_are_input__output_in_same_format(
+        self
+    ):
+
+        coordinates_input = MockCoordinateInput()
+
+        coordinates = aa.coordinates(
+            coordinates=[[(1.0, 2.0), (3.0, 4.0)], [(5.0, 6.0)]]
+        )
+
+        coordinates_output = coordinates_input.float_values_from_grid(grid=coordinates)
+
+        assert coordinates_output == [[1.0, 1.0], [1.0]]
+
+        coordinates_output = coordinates_input.tuple_values_from_grid(grid=coordinates)
+
+        assert coordinates_output == [[(2.0, 4.0), (6.0, 8.0)], [(10.0, 12.0)]]
+
+    def test__convert_coordinates_decorator__same_as_above_but_output_is_a_list(self):
+
+        coordinates_input = MockCoordinateInput()
+
+        coordinates = aa.coordinates(
+            coordinates=[[(1.0, 2.0), (3.0, 4.0)], [(5.0, 6.0)]]
+        )
+
+        coordinates_output = coordinates_input.float_values_from_grid_returns_list(
+            grid=coordinates
+        )
+
+        assert coordinates_output == [[[1.0, 1.0], [1.0]], [[2.0, 2.0], [2.0]]]
+
+        coordinates_output = coordinates_input.tuple_values_from_grid_returns_list(
+            grid=coordinates
+        )
+
+        assert coordinates_output == [
+            [[(1.0, 2.0), (3.0, 4.0)], [(5.0, 6.0)]],
+            [[(2.0, 4.0), (6.0, 8.0)], [(10.0, 12.0)]],
         ]
